summaryrefslogtreecommitdiff
path: root/include/plugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/plugin.h')
-rw-r--r--include/plugin.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/plugin.h b/include/plugin.h
index fa167b7..e3073f4 100644
--- a/include/plugin.h
+++ b/include/plugin.h
@@ -473,12 +473,12 @@ protected:
* - change of the parent container, where the file or container
* was moved to
*
* The optional target must be an element inside the container
* specified in the URI. If the target is not empty, only this
* element will be checked for changes. Otherwise the full container
* is scanned.
*/
- void OnContainerUpdate(const string& uri, long containerUpdateId, const string& target = string());
+ void OnContainerUpdate(const string& uri, long containerUpdateId, const StringList& target = StringList());
/**
* Load a configuration file.
@@ -473,12 +473,12 @@ protected:
* was moved to
*
- * The optional target must be an element inside the container
- * specified in the URI. If the target is not empty, only this
- * element will be checked for changes. Otherwise the full container
+ * The optional target list contains elements inside the container
+ * specified in the URI. If the target list is not empty, only those
+ * elements will be checked for changes. Otherwise the full container
* is scanned.
*/